@@ -8,7 +8,7 @@ require Exporter;
 use warnings;
 use strict;
 use Carp;
-our $VERSION = '0.08_01';
+our $VERSION = '0.01';
 require XSLoader;
 XSLoader::load ('Image::PNG::QRCode', $VERSION);
 
@@ -60,51 +60,18 @@ sub qrpng
 	    croak "Bad level number $options{level}: use integer between one and four";
 	}
     }
-    if ($options{size}) {
-	if (ref $options{size} ne 'SCALAR') {
-	    carp "size option requires a scalar reference";
-	    delete $options{size};
-	}
-    }
-    # If true, user will use the return value.
-    my $r;
-    # If true, user wants to write the PNG data into a scalar.
-    my $s;
-    # Check what kind of output the user wants.
-    if (defined (wantarray ())) {
-	# User wants a return value.
+    my $r = defined wantarray () && ! wantarray ();
+    my $s = $options{out} && ref $options{out} eq 'SCALAR';
+    if ($r || $s) {
 	$options{out_sv} = 1;
-	$r = 1;
-    }
-    if ($options{out}) {
-	if (ref $options{out} eq 'SCALAR') {
-	    # User wants to write the PNG data into a scalar.
-	    $options{out_sv} = 1;
-	    $s = 1;
-	    if ($r) {
-		# User wants both the return value and to use as
-		# scalar, for some reason.
-		carp "Return value used twice";
-	    }
-	}
-	# Else user wants to write the PNG data to a file.
-    }
-    else {
-	if (! $r) {
-	    # Don't know what the user wants, tell them they haven't
-	    # specified how to output and give up.
-	    carp "Output discarded: use return value or specify 'out => \\\$value'";
-	    return undef;
-	}
     }
     qrpng_internal (\%options);
-    if ($s) {
+    if ($r) {
+	return ${$options{png_data}};
+    }
+    elsif ($s) {
 	${$options{out}} = $options{png_data};
     }
-    if ($r) {
-	return $options{png_data};
-    }
-    return undef;
 }
 
 1;
